@@ -58,6 +58,7 @@ enum
   PROP_0,
   PROP_NAME,
   PROP_STATE,
+  PROP_STATS,
   PROP_WIRELESS,
   PROP_SIGNAL_STRENGTH,
   PROP_ERROR
@@ -68,10 +69,7 @@ struct _NetstatusIfacePrivate
   char           *name;
 
   NetstatusState  state;
-  long            in_packets;
-  long            out_packets;
-  long            in_bytes;
-  long            out_bytes;
+  NetstatusStats  stats;
   int             signal_strength;
   GError         *error;
 
@@ -166,6 +164,14 @@ netstatus_iface_class_init (NetstatusIfaceClass *klass)
 						      NETSTATUS_STATE_DISCONNECTED,
 						      G_PARAM_READABLE));
 
+  g_object_class_install_property (gobject_class,
+				   PROP_STATS,
+				   g_param_spec_boxed ("stats",
+						       _("Stats"),
+						       _("The interface packets/bytes statistics"),
+						       NETSTATUS_TYPE_STATS,
+						       G_PARAM_READABLE));
+
   g_object_class_install_property (gobject_class,
 				   PROP_WIRELESS,
 				   g_param_spec_boolean ("wireless",
@@ -257,6 +263,9 @@ netstatus_iface_get_property (GObject    *object,
     case PROP_STATE:
       g_value_set_enum (value, iface->priv->state);
       break;
+    case PROP_STATS:
+      g_value_set_boxed (value, &iface->priv->stats);
+      break;
     case PROP_WIRELESS:
       g_value_set_boolean (value, iface->priv->is_wireless);
       break;
@@ -321,29 +330,13 @@ netstatus_iface_get_state (NetstatusIface *iface)
 }
 
 void
-netstatus_iface_get_packet_statistics (NetstatusIface *iface,
-				       long           *in,
-				       long           *out)
+netstatus_iface_get_statistics (NetstatusIface *iface,
+				NetstatusStats *stats)
 {
   g_return_if_fail (NETSTATUS_IS_IFACE (iface));
 
-  if (in)
-    *in  = iface->priv->in_packets;
-  if (out)
-    *out = iface->priv->out_packets;
-}
-
-void
-netstatus_iface_get_byte_statistics (NetstatusIface *iface,
-				     long           *in,
-				     long           *out)
-{
-  g_return_if_fail (NETSTATUS_IS_IFACE (iface));
-
-  if (in)
-    *in = iface->priv->in_bytes;
-  if (out)
-    *out = iface->priv->out_bytes;
+  if (stats)
+    *stats  = iface->priv->stats;
 }
 
 gboolean
@@ -524,13 +517,13 @@ netstatus_iface_poll_state (NetstatusIface *iface)
 
   dprintf (POLLING, "Packets in: %ld out: %ld. Prev in: %ld out: %ld\n",
 	   in_packets, out_packets,
-	   iface->priv->in_packets, iface->priv->out_packets);
+	   iface->priv->stats.in_packets, iface->priv->stats.out_packets);
   dprintf (POLLING, "Bytes in: %ld out: %ld. Prev in: %ld out: %ld\n",
 	   in_bytes, out_bytes,
-	   iface->priv->in_bytes, iface->priv->out_bytes);
+	   iface->priv->stats.in_bytes, iface->priv->stats.out_bytes);
   
-  rx = in_packets  > iface->priv->in_packets;
-  tx = out_packets > iface->priv->out_packets;
+  rx = in_packets  > iface->priv->stats.in_packets;
+  tx = out_packets > iface->priv->stats.out_packets;
 
   if (!tx && !rx)
     state = NETSTATUS_STATE_IDLE;
@@ -541,13 +534,18 @@ netstatus_iface_poll_state (NetstatusIface *iface)
   else /* if (rx) */
     state = NETSTATUS_STATE_RX;
 
-  iface->priv->in_packets  = in_packets;
-  iface->priv->out_packets = out_packets;
-  iface->priv->in_bytes    = in_bytes;
-  iface->priv->out_bytes   = out_bytes;
-
   dprintf (POLLING, "State: %s\n", netstatus_get_state_string (state));
 
+  if (tx || rx)
+    {
+      iface->priv->stats.in_packets  = in_packets;
+      iface->priv->stats.out_packets = out_packets;
+      iface->priv->stats.in_bytes    = in_bytes;
+      iface->priv->stats.out_bytes   = out_bytes;
+
+      g_object_notify (G_OBJECT (iface), "stats");
+    }
+
   return state;
 }
 
@@ -648,12 +646,12 @@ netstatus_iface_monitor_timeout (NetstatusIface *iface)
 static void
 netstatus_iface_init_monitor (NetstatusIface *iface)
 {
-  iface->priv->in_packets      = 0;
-  iface->priv->out_packets     = 0;
-  iface->priv->in_bytes        = 0;
-  iface->priv->out_bytes       = 0;
-  iface->priv->signal_strength = 0;
-  iface->priv->is_wireless     = FALSE;
+  iface->priv->stats.in_packets  = 0;
+  iface->priv->stats.out_packets = 0;
+  iface->priv->stats.in_bytes    = 0;
+  iface->priv->stats.out_bytes   = 0;
+  iface->priv->signal_strength   = 0;
+  iface->priv->is_wireless       = FALSE;
 
   g_object_freeze_notify (G_OBJECT (iface));
   g_object_notify (G_OBJECT (iface), "state");
